pub struct Reason {
pub message: String,
pub reason_code: Option<ReasonCode>,
pub links: Option<Vec<Link>>,
}Expand description
Reason : A reason for the restriction, including path forward links that may allow Selling Partners to remove the restriction, if available.
Fields
message: StringA message describing the reason for the restriction.
reason_code: Option<ReasonCode>A code indicating why the listing is restricted.
links: Option<Vec<Link>>A list of path forward links that may allow Selling Partners to remove the restriction.
Implementations